@@ -16,7 +16,7 @@ use Readonly;
 Readonly my $ENTRY_WIDTH_DATE     => 10;
 Readonly my $ENTRY_WIDTH_DATETIME => 19;
 
-our $VERSION = '2.13.1';
+our $VERSION = '2.13.2';
 my $EMPTY           = q{};
 my $DATE_FORMAT     = '%04d-%02d-%02d';
 my $DATETIME_FORMAT = '%04d-%02d-%02d %02d:%02d:%02d';
@@ -247,7 +247,7 @@ sub GET_PROPERTY {
                     {
                         $self->{$name} = [
                             Gscan2pdf::Document::text_to_datetime(
-                                $self->{$name}
+                                $self->{$name}, Today()
                             )
                         ];
                     }
@@ -355,10 +355,10 @@ sub add_metadata {
     $self->{'meta-datetime-widget'}->signal_connect(
         'focus-out-event' => sub {
             my $text = $self->{'meta-datetime-widget'}->get_text;
-            if ( defined $text and $text ne $EMPTY ) {
+            if ( defined $text ) {
                 $self->{'meta-datetime-widget'}->set_text(
                     $self->datetime2string(
-                        Gscan2pdf::Document::text_to_datetime($text)
+                        Gscan2pdf::Document::text_to_datetime($text), Today()
                     )
                 );
             }
@@ -381,7 +381,7 @@ sub add_metadata {
             # focus-out-event, so update the date now
             my ( $year, $month, $day, $hour, $min, $sec ) =
               Gscan2pdf::Document::text_to_datetime(
-                $self->{'meta-datetime-widget'}->get_text );
+                $self->{'meta-datetime-widget'}->get_text, Today() );
 
             $calendar->select_day($day);
             $calendar->select_month( $month - 1, $year );
@@ -504,7 +504,7 @@ sub insert_text_handler {
         $widget->set_text(
             $self->datetime2string(
                 Add_Delta_DHMS(
-                    Gscan2pdf::Document::text_to_datetime($text),
+                    Gscan2pdf::Document::text_to_datetime( $text, Today() ),
                     $offset, 0, 0, 0
                 )
             )
@@ -802,8 +802,8 @@ sub add_pdf_options {
             'lzw', __('LZW'),
             __('Compress output with Lempel-Ziv & Welch encoding.')
         ],
-        [ 'g3', __('G3'), __('Compress output with CCITT Group 3 encoding.') ],
-        [ 'g4', __('G4'), __('Compress output with CCITT Group 4 encoding.') ],
+        [ 'g3',  __('G3'), __('Compress output with CCITT Group 3 encoding.') ],
+        [ 'g4',  __('G4'), __('Compress output with CCITT Group 4 encoding.') ],
         [ 'png', __('Flate'), __('Compress output with flate encoding.') ],
         [ 'jpg', __('JPEG'),  __('Compress output with JPEG (DCT) encoding.') ],
         [ 'none', __('None'), __('Use no compression algorithm on output.') ],
