@@ -296,7 +296,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::, signals => {
     ),
   ];
 
-our $VERSION = '2.13.1';
+our $VERSION = '2.13.2';
 
 my ( $d_sane, $logger );
 my $SANE_NAME_SCAN_TL_X   = SANE_NAME_SCAN_TL_X;
@@ -1337,7 +1337,8 @@ sub create_paper_widget {
                 }
                 elsif ( $self->{combobp}->get_active_text eq __('Manual') ) {
                     for (
-                        ( SANE_NAME_SCAN_TL_X, SANE_NAME_SCAN_TL_Y,
+                        (
+                            SANE_NAME_SCAN_TL_X,   SANE_NAME_SCAN_TL_Y,
                             SANE_NAME_SCAN_BR_X,   SANE_NAME_SCAN_BR_Y,
                             SANE_NAME_PAGE_HEIGHT, SANE_NAME_PAGE_WIDTH
                         )
@@ -1359,7 +1360,8 @@ sub create_paper_widget {
         # If the geometry is changed, unset the paper size,
         # if we are not setting a profile
         for (
-            ( SANE_NAME_SCAN_TL_X, SANE_NAME_SCAN_TL_Y,
+            (
+                SANE_NAME_SCAN_TL_X,   SANE_NAME_SCAN_TL_Y,
                 SANE_NAME_SCAN_BR_X,   SANE_NAME_SCAN_BR_Y,
                 SANE_NAME_PAGE_HEIGHT, SANE_NAME_PAGE_WIDTH
             )
@@ -1385,7 +1387,8 @@ sub create_paper_widget {
 sub hide_geometry {
     my ( $self, $options ) = @_;
     for (
-        ( SANE_NAME_SCAN_TL_X, SANE_NAME_SCAN_TL_Y,
+        (
+            SANE_NAME_SCAN_TL_X,   SANE_NAME_SCAN_TL_Y,
             SANE_NAME_SCAN_BR_X,   SANE_NAME_SCAN_BR_Y,
             SANE_NAME_PAGE_HEIGHT, SANE_NAME_PAGE_WIDTH
         )
@@ -1651,28 +1654,34 @@ sub set_paper {
         and not $options->by_name(SANE_NAME_PAGE_WIDTH)->{cap} &
         SANE_CAP_INACTIVE )
     {
-        $paper_profile->add_backend_option( SANE_NAME_PAGE_HEIGHT,
+        $paper_profile->add_backend_option(
+            SANE_NAME_PAGE_HEIGHT,
             $formats->{$paper}{y} + $formats->{$paper}{t},
             $options->by_name(SANE_NAME_PAGE_HEIGHT)->{val}
         );
-        $paper_profile->add_backend_option( SANE_NAME_PAGE_WIDTH,
+        $paper_profile->add_backend_option(
+            SANE_NAME_PAGE_WIDTH,
             $formats->{$paper}{x} + $formats->{$paper}{l},
             $options->by_name(SANE_NAME_PAGE_WIDTH)->{val}
         );
     }
-    $paper_profile->add_backend_option( SANE_NAME_SCAN_TL_X,
+    $paper_profile->add_backend_option(
+        SANE_NAME_SCAN_TL_X,
         $formats->{$paper}{l},
         $options->by_name(SANE_NAME_SCAN_TL_X)->{val}
     );
-    $paper_profile->add_backend_option( SANE_NAME_SCAN_TL_Y,
+    $paper_profile->add_backend_option(
+        SANE_NAME_SCAN_TL_Y,
         $formats->{$paper}{t},
         $options->by_name(SANE_NAME_SCAN_TL_Y)->{val}
     );
-    $paper_profile->add_backend_option( SANE_NAME_SCAN_BR_X,
+    $paper_profile->add_backend_option(
+        SANE_NAME_SCAN_BR_X,
         $formats->{$paper}{x} + $formats->{$paper}{l},
         $options->by_name(SANE_NAME_SCAN_BR_X)->{val}
     );
-    $paper_profile->add_backend_option( SANE_NAME_SCAN_BR_Y,
+    $paper_profile->add_backend_option(
+        SANE_NAME_SCAN_BR_Y,
         $formats->{$paper}{y} + $formats->{$paper}{t},
         $options->by_name(SANE_NAME_SCAN_BR_Y)->{val}
     );
